/*==============================================================================*/
/*  Copyright (C) 2020, Heartland Data inc. All Rights Reserved.                */
/*                                                                              */
/*  Title  :   CAN Driver                                                       */
/*  EventID:   Insert EventID Test Point/Insert Extended EventID Test Point     */
/*  AppVer :   DT+ Ver1.00`                                                    */
/*  FileID :   18a                                                              */
/*  Version:   1.0                                                              */
/*  Author :   HLDC                                                             */
/*==============================================================================*/

/*==============================================================================*/
/*  Please customize the code for you environment.                              */
/*==============================================================================*/

/*==============================================================================*/
/*  Desc:  Header for Port Controll                                             */
/*==============================================================================*/
#include "Common.h"

/*==============================================================================*/
/*  Macro:  DT_UINT                                                             */
/*  Desc:   Please chage Test Point argument type for DT+ Project setting.      */
/*==============================================================================*/
#define	DT_UINT unsigned int

/*==============================================================================*/
/*   Don't change the code from here as possible.                               */
/*==============================================================================*/

/*==============================================================================*/
/*   Desc:  Test Point ID                                                       */
/*==============================================================================*/
#define		DT_VARIABLE_BIT			0x02
#define		DT_EVTTRG_BIT			0x08
#define		DT_VARIABLE_FAST_BIT		0x01
#define		DT_EVTTRG_FAST_BIT		0x02

/*==============================================================================*/
/*   Func:  _TP_BusOut                                                          */
/*   Desc:  Called by Test Point                                                */
/*==============================================================================*/
void _TP_BusOut( DT_UINT addr, DT_UINT dat )
{
	unsigned char tmp[4];

	tmp[0] = addr ;
	tmp[1] = addr >> 8;
	tmp[2] = dat ;
	tmp[3] = dat >> 8;
	CanDataSend( tmp, 4 );
}

/*==============================================================================*/
/*   Func:  _TP_MemoryOutput                                                    */
/*   Desc:  Called by Variable Test Point                                       */
/*==============================================================================*/
void _TP_MemoryOutput( DT_UINT addr, DT_UINT dat, void *value, DT_UINT size )
{
	unsigned char tmp[8];
	unsigned char *p = value;
	int	i;

	tmp[0] = addr | 0x02;
	tmp[1] = addr >> 8;
	tmp[2] = dat ;
	tmp[3] = dat >> 8;
	for( i = 0; i < 4; i++, p++ ){
		tmp[4+i] = (i < size)?*p:0x00;
	}
	CanDataSend( tmp, 4 + size );
}

/*==============================================================================*/
/*  Func:  _TP_EventTrigger                                                     */
/*  Desc:  Called by Event Trigger Test Point                                   */
/*==============================================================================*/
void _TP_EventTrigger( DT_UINT addr, DT_UINT dat, DT_UNIT event_id )
{
}

/*==============================================================================*/
